@@ -80,6 +80,9 @@ def octet2date(txt):
     elif year > 3000:
         hexadecimal = False
         year = int(txt[0:4])
+    elif year == 0:
+        hexadecimal = False
+        year = 0000
     month = hexadecimal and octet2number(txt[4:6]) or int(txt[4:6])
     if month < 1 or month > 12:
         month = 1
